==> dhall-json-1.7.12-133-riscv64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-json
version:              1.7.12
visibility:           public
id:                   dhall-json-1.7.12-4GFbXfWHFd4DzAskTLy2Cq
key:                  dhall-json-1.7.12-4GFbXfWHFd4DzAskTLy2Cq
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  b1b4e0ff190d03573bc4f6263d3b2812
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Compat Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.12-4GFbXfWHFd4DzAskTLy2Cq
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    aeson-pretty-0.8.10-FQa8xIJIIpZJMrtrbu8IN4
    aeson-yaml-1.1.0.1-qbTnQYg4UDFsg9b7of1Rh base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.3-4nYYNMOVNunEFpgl2kICyh exceptions-0.10.5
    filepath-1.4.2.2 lens-family-core-2.1.3-Ij4qXDXH4U49wX5TL83dlV
    optparse-applicative-0.18.1.0-3qYZezrQAxc4lJKAil0WN1
    prettyprinter-1.7.1-18Jm3UFnGYW2Ifx2izjEAg
    scientific-0.3.8.0-L88GQ4rEhQfGc3NVSCAVTu text-2.0.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-json-1.7.12-156-riscv64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-json
version:              1.7.12
visibility:           public
id:                   dhall-json-1.7.12-3G7taIDoeSW9B6eMftZMI2
key:                  dhall-json-1.7.12-3G7taIDoeSW9B6eMftZMI2
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  6039dac4e7d2d206dd315ed42b011b94
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Compat Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.12-3G7taIDoeSW9B6eMftZMI2
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    aeson-pretty-0.8.10-7oLs7OTWYk9GnMVCodyIc4
    aeson-yaml-1.1.0.1-4YQukpVafuk6BplBgyV098 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.3-HeTEhICrwINHKsGOfVjnsv exceptions-0.10.5
    filepath-1.4.2.2 lens-family-core-2.1.3-Ij4qXDXH4U49wX5TL83dlV
    optparse-applicative-0.18.1.0-t4C6chS8YH5x9x9VuRkT0
    prettyprinter-1.7.1-IxfK3MMc5TsGC7SkX421m7
    scientific-0.3.8.0-6QoqQGQc0yZ1FsULZsdy9C text-2.0.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
